@@ -57,11 +57,11 @@ class SignalParalleLauncher():
                 sqliteConnection.close()
                 print("sqlite connection is closed")
 
-    def addRun(self,run):
+    def addRunTurnOver(self,run):
         sqliteConnection = None
         try:
             sqliteConnection = sqlite3.connect(self.db_path)
-            sqlite_create_table_query = 'alter table parallel_run add column ' + run + '_perf_return real, '+run+'_turn_over real'
+            sqlite_create_table_query = 'alter table parallel_run add column ' + run + '_turn_over real'
             cursor = sqliteConnection.cursor()
             print("Successfully Connected to SQLite")
             cursor.execute(sqlite_create_table_query)
@@ -76,15 +76,34 @@ class SignalParalleLauncher():
                 sqliteConnection.close()
                 print("sqlite connection is closed")  # adding the column
 
-    def insertResults(self, run, signal_results_df):
+    def addRunPerf(self,run):
+        sqliteConnection = None
+        try:
+            sqliteConnection = sqlite3.connect(self.db_path)
+            sqlite_create_table_query = 'alter table parallel_run add column ' + run + '_perf_return real'
+            cursor = sqliteConnection.cursor()
+            print("Successfully Connected to SQLite")
+            cursor.execute(sqlite_create_table_query)
+            sqliteConnection.commit()
+            print("SQLite table created")
+            cursor.close()
+            self.runs.append(run)
+        except sqlite3.Error as error:
+            print("Error while creating a sqlite table", error)
+        finally:
+            if (sqliteConnection):
+                sqliteConnection.close()
+                print("sqlite connection is closed")  # adding the column
+
+    def insertResults(self, run, values):
         sqliteConnection = None
         try:
             success = True
             sqliteConnection = sqlite3.connect(self.db_path)
             cursor = sqliteConnection.cursor()
-            for date_index, row in signal_results_df.iterrows():
-                sqlite_insert_query = """INSERT INTO 'parallel_run' ('effective_date', '""" +run +"""_perf_return','"""+run +"""_turn_over')"""+""" VALUES ('""" + str(
-                    date_index) + """','""" + str(row['perf_return']) + """','""" + str(row['turn_over']) + """');"""
+            for i, v in values.iteritems():
+                sqlite_insert_query = """INSERT INTO 'parallel_run' ('effective_date', '""" + run + """') VALUES ('""" + str(
+                    i) + """','""" + str(v) + """');"""
                 cursor.execute(sqlite_insert_query)
             sqliteConnection.commit()
             cursor.close()
@@ -115,6 +134,50 @@ class SignalParalleLauncher():
                 sqliteConnection.close()
                 print("The Sqlite connection is closed")
 
+    def insertPerfTurnOverResults(self, run, signal_results_df):
+        sqliteConnection = None
+        try:
+            success = True
+            sqliteConnection = sqlite3.connect(self.db_path)
+            cursor = sqliteConnection.cursor()
+            for date_index, row in signal_results_df.iterrows():
+                sqlite_insert_query = """INSERT INTO 'parallel_run' ('effective_date', '""" +run +"""_perf_return','"""+run +"""_turn_over')"""+""" VALUES ('""" + str(
+                    date_index) + """','""" + str(row['perf_return']) + """','""" + str(row['turn_over']) + """');"""
+                cursor.execute(sqlite_insert_query)
+            sqliteConnection.commit()
+            cursor.close()
+        except sqlite3.Error as error:
+            print("Error while working with SQLite", error)
+            success = False
+        finally:
+            if (sqliteConnection):
+                sqliteConnection.close()
+                print("The Sqlite connection is closed")
+        return success
+
+    def updatePerfTurnOverResults(self, run, signal_results_df):
+        sqliteConnection = None
+        try:
+            sqliteConnection = sqlite3.connect(self.db_path)
+            cursor = sqliteConnection.cursor()
+            for date_index, row in signal_results_df.iterrows():
+                sqlite_update_query = """UPDATE 'parallel_run' set ('""" + run + """_perf_return','""" + run + """_turn_over')""" + """ = ('""" + str(
+                    row['perf_return']) + """','""" + str(row['turn_over']) + """') where effective_date = '""" + str(
+                    date_index) + """'"""
+                cursor.execute(sqlite_update_query)
+            sqliteConnection.commit()
+            cursor.close()
+        except sqlite3.Error as error:
+            print("Error while working with SQLite", error)
+        finally:
+            if (sqliteConnection):
+                sqliteConnection.close()
+                print("The Sqlite connection is closed")
+
+    def addPerfTurnOverResults(self, run, values):
+        success = self.insertPerfTurnOverResults(run,values)
+        if not success :
+            self.updatePerfTurnOverResults(run, values)
 
 
     def addResults(self, run, values):
@@ -122,9 +185,29 @@ class SignalParalleLauncher():
         if not success :
             self.updateResults(run, values)
 
+    def addRun(self,run):
+        sqliteConnection = None
+        try:
+            sqliteConnection = sqlite3.connect(self.db_path)
+            sqlite_create_table_query = 'alter table parallel_run add column ' + run + ' real'
+            cursor = sqliteConnection.cursor()
+            print("Successfully Connected to SQLite")
+            cursor.execute(sqlite_create_table_query)
+            sqliteConnection.commit()
+            print("SQLite table created")
+            cursor.close()
+            self.runs.append(run)
+        except sqlite3.Error as error:
+            print("Error while creating a sqlite table", error)
+        finally:
+            if (sqliteConnection):
+                sqliteConnection.close()
+                print("sqlite connection is closed")  # adding the column
 
     def saveResults(self, run, strat_results_df):
         self.addRun(run)
+        #self.addRunPerf(run)
+        #self.addRunTurnOver(run)
         self.addResults(run, strat_results_df)
 
 
